import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.sql.SQLException;
import java.util.Scanner;

public class AccountApp {

    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";
    private Dao<Account, Integer> accountDao;

    private Scanner scanner = new Scanner(System.in);

    public AccountApp(){
        try {
            ConnectionSource connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "");
            setupDao(connectionSource);
            connectionSource.close();
        } catch (SQLException e) {
            e.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    public static void main(String[] args) throws Exception {
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        processData();
    }

    private void processData() throws Exception {
        Scanner scanner = new Scanner(System.in);
        String userInteracting = "yes";
        while (userInteracting.equals("yes")) {
            printWelcomeMessageAndMenu();
            int crudChoice = Integer.parseInt(scanner.nextLine());
            switch(crudChoice){
                case (1) :
                    System.out.println("Enter name of user:");
                    String name = scanner.nextLine();
                    System.out.println("Enter password of user:");
                    String password = scanner.nextLine();
                    Account account = createAccountObject(name, password);
                    createAccount(account);
                    break;
                case (2) :
                    System.out.println("Enter id of user to read:");
                    int id = Integer.parseInt(scanner.nextLine());
                    Account readAccount = readAccountByID(id);
                    printAccountDetails(readAccount);
                    break;
                case (3) :
                    System.out.println("Enter id of user to update name of:");
                    id = Integer.parseInt(scanner.nextLine());
                    readAccount = readAccountByID(id);
                    printAccountDetails(readAccount);
                    System.out.println("Enter new name");
                    name = scanner.nextLine();
                    updateAccountName(readAccount, name);
                    break;
                case (4) :
                    System.out.println("Enter id of user to update password of:");
                    id = Integer.parseInt(scanner.nextLine());
                    readAccount = readAccountByID(id);
                    printAccountDetails(readAccount);
                    System.out.println("Enter new password");
                    password = scanner.nextLine();
                    updateAccountName(readAccount, password);
                    break;
                case (5) :
                    System.out.println("Enter id of user to delete:");
                    id = Integer.parseInt(scanner.nextLine());
                    readAccount = readAccountByID(id);
                    deleteAccount(readAccount);
                    break;
                default :
                    System.out.println("Not a valid choice");
            }
            System.out.println("Enter yes to make more changes\n" +
                    "Enter anything else to quit");
            userInteracting = scanner.nextLine();
        }
    }

    public void printWelcomeMessageAndMenu(){
        System.out.println("Welcome to the Account Database Editor.\n " +
                "Select an option from our CRUD menu by entering the number:\n" +
                "1. Create user\n" +
                "2. Read user\n" +
                "3. Update user name\n" +
                "4. Update user password\n" +
                "5. Delete user");
    }

    private void printAccountDetails(Account a) {
        String id = String.valueOf(a.getId());
        String name = a.getName();
        System.out.println("ID: " + id + " Name: " + name + " Password: Nice Try!");
    }

    public Account createAccountObject(String name, String password){
        return new Account(name, password);
    }

    public void createAccount(Account account) throws SQLException {
        accountDao.create(account);
    }

    public Account readAccountByID(int id) throws SQLException {
        return accountDao.queryForId(id);
    }

    public Account readAccountByObject(Account a) throws SQLException {
        return accountDao.queryForSameId(a);
    }

    public void updateAccountName(Account a, String name) throws SQLException {
        a.setName(name);
        accountDao.update(a);
    }

    public void updateAccountPassword(Account a, String password) throws SQLException {
        a.setPassword(password);
        accountDao.update(a);
    }

    public void deleteAccount(Account a) throws SQLException {
        accountDao.delete(a);
    }

    private void setupDao(ConnectionSource connectionSource) throws Exception {
        accountDao = DaoManager.createDao(connectionSource, Account.class);
    }
}
