import static org.junit.Assert.*;
import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;
import org.junit.Test;
import java.sql.SQLException;
import java.sql.SQLOutput;

public class AccountAppTest {

    @Test
    public void createAccountObjectNameTest(){
        //Given
        String name = "John";
        String password = "password";
        //Actual
        Account account = new Account(name, password);
        String actualName = account.getName();
        //Expected
        assertEquals(name, actualName);
    }

    @Test
    public void createAccountObjectPasswordTest(){
        //Given
        String name = "John";
        String password = "password";
        //Actual
        Account account = new Account(name, password);
        String actualPassword = account.getPassword();
        //Expected
        assertEquals(password, actualPassword);
    }

    @Test
    public void createAccountTest() throws SQLException {
        //Given
        AccountApp accountApp = new AccountApp();
        Account expected = new Account("John Doe", "password");
        accountApp.createAccount(expected);
        //Actual
        Account actual = accountApp.readAccountByObject(expected);
        //Expected
        assertEquals(expected, actual);
    }

    @Test
    public void readAccountTest() throws SQLException {
        //Given
        AccountApp accountApp = new AccountApp();
        Account expected = new Account("Jane Doe", "password");
        accountApp.createAccount(expected);
        //Actual
        Account actual = accountApp.readAccountByObject(expected);
        //Expected
        assertEquals(expected, actual);
    }

    @Test
    public void updateAccountPasswordName() throws SQLException {
        //Given
        AccountApp accountApp = new AccountApp();
        Account originalAccount = new Account("Update Doe", "password");
        accountApp.createAccount(originalAccount);
        accountApp.updateAccountName(originalAccount, "Update Update");
        //Actual
        Account updateAccount = accountApp.readAccountByObject(originalAccount);
        String actual = originalAccount.getName();
        //Expected
        String expected = "Update Update";
        assertEquals(expected, actual);
    }

    @Test
    public void updateAccountPasswordTest() throws SQLException {
        //Given
        AccountApp accountApp = new AccountApp();
        Account originalAccount = new Account("Update Doe", "password");
        accountApp.createAccount(originalAccount);
        accountApp.updateAccountPassword(originalAccount, "password1");
        //Actual
        Account updateAccount = accountApp.readAccountByObject(originalAccount);
        String actual = originalAccount.getPassword();
        //Expected
        String expected = "password1";
        assertEquals(expected, actual);
    }

    @Test
    public void deleteAccountTest() throws SQLException {
        //Given
        AccountApp accountApp = new AccountApp();
        Account expected = new Account("Delete Doe", "password");
        accountApp.createAccount(expected);
        //Actual
        accountApp.deleteAccount(expected);
        //Expected
        Account actual = accountApp.readAccountByObject(expected);
        assertNull(actual);
    }
}
